@@ -1,4 +1,6 @@
-## ---- include = FALSE----------------------------------------------------
+## ---- include = FALSE---------------------------------------------------------
+options(rmarkdown.html_vignette.check_title = FALSE)
+
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>"
@@ -19,17 +21,17 @@ library(stringr)
 library(scales)
 library(knitr)
 
-## ----pull_data-----------------------------------------------------------
+## ----pull_data----------------------------------------------------------------
 west_virginia <- total_pharmacies_state(state="WV", key="WaPo")
 
 kable(head(west_virginia))
 
-## ----population----------------------------------------------------------
+## ----population---------------------------------------------------------------
 population <- county_population(state="WV", key="WaPo")
 
 kable(head(population))
 
-## ----population_refined--------------------------------------------------
+## ----population_refined-------------------------------------------------------
 population <- population %>% 
   group_by(BUYER_COUNTY, BUYER_STATE, countyfips) %>% 
   # Figure out the average population between available years
@@ -42,13 +44,13 @@ wv_joined <- left_join(west_virginia, population)
 
 kable(head(wv_joined))
 
-## ----join----------------------------------------------------------------
+## ----join---------------------------------------------------------------------
 wv_joined <- wv_joined %>% 
   mutate(per_person=total_dosage_unit/average_population/7)
 
 kable(head(wv_joined))
 
-## ----colors--------------------------------------------------------------
+## ----colors-------------------------------------------------------------------
 
 ## Get a list of addresses because it includes BUYER_BUS_ACT information
 pharmacy_list <- buyer_addresses(state="WV", key="WaPo")
